<?php
// Own namespace
namespace CoreFramework\Filter\Verifier\User;

// Import framework stuff
use CoreFramework\Filter\BaseFilter;
use CoreFramework\Filter\Filterable;
use CoreFramework\Registry\Registry;
use CoreFramework\Request\Requestable;
use CoreFramework\Response\Responseable;

/**
 * A filter for checking if user status is UNCONFIRMED.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class UserUnconfirmedVerifierFilter extends BaseFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createUserUnconfirmedVerifierFilter () {
		// Get a new instance
		$filterInstance = new UserUnconfirmedVerifierFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get a user instance for comparison
		$userInstance = UserFactory::createUserByRequest($requestInstance);

		// Is the email address valid?
		if ($userInstance->ifEmailAddressExists() === FALSE) {
			// Request is invalid!
			$requestInstance->requestIsValid(FALSE);

			// Redirect to configured URL
			$responseInstance->redirectToConfiguredUrl('user_unconfirmed_email_missing');

			// Stop processing here
			exit();
		} // END - if

		// Is the user account confirmed?
		if ($userInstance->getField(UserDatabaseWrapper::DB_COLUMN_USER_STATUS) != $this->getConfigInstance()->getConfigEntry('user_status_unconfirmed')) {
			// Request is invalid!
			$requestInstance->requestIsValid(FALSE);

			// Redirect to configured URL
			$responseInstance->redirectToConfiguredUrl('user_not_unconfirmed');

			// Stop processing here
			exit();
		} // END - if

		// Add this instance to registry
		Registry::getRegistry()->addInstance('user', $userInstance);
	}

}
